@@ -1,12 +1,6 @@
 # -*- coding: utf-8 -*-
 # -*- mode: python -*-
 """Functions for interpreting and analyzing model output"""
-# python 3 compatibility
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import division
-from __future__ import unicode_literals
-
 from spyks import core
 
 
@@ -14,6 +8,7 @@ def state_fun(model, state):
     """Create a lambda that will evaluate functions of the model state"""
     from spyks.codegen import state_replacements
     from spyks.validate import evalf
+
     repl = state_replacements(model)
     units = [v.units for n, v in model["state"]]
     context = {"X": [state[:, i] * u for i, u in enumerate(units)]}
